[![GitHub Workflow Documentation](https://img.shields.io/github/actions/workflow/status/mytoolit/ICOtronic/documentation.yaml?branch=main&label=GitHub%20Pages)](https://mytoolit.github.io/ICOtronic/) [![Read the Docs ](https://img.shields.io/readthedocs/icotronic?label=Read%20the%20Docs)](https://icotronic.readthedocs.io/en/stable/) [![GitHub Workflow Tests](https://img.shields.io/github/actions/workflow/status/mytoolit/ICOtronic/tests.yaml?branch=main&label=Tests)](https://github.com/MyTooliT/ICOtronic/actions/workflows/tests.yaml)

# ICOtronic

This repository contains a data collection library for the [ICOtronic system](https://www.mytoolit.com/ICOtronic/). For more information, please take a look [at the online documentation](https://mytoolit.github.io/ICOtronic/).
